==> tecfy_corev2_package-1.1.78.tar.gz: lib/services/report.service.dart <==
part of tecfy_corev2_client_package;

class ReportDataService {
  static Future onOpenReport(BuildContext context, Map<String, dynamic> report,
      [List<EntityFilter>? defaultFilter]) async {
    // AppNavigator.navigateTo(context, ()=>ReportFilterPage(report));
    try {
      List<EntityFilter> filter = [];
      bool canceled = false;
      if (report['filters'].length > 0) {
        var result = await AppNavigator.showAppDialog(
            context,
            (c) => EntityFilterPage(
                report['filters'].map<Property>((r) {
                  var prop = Property.getProperty(r);
                  //prop.isVisable = true;
                  prop?.isAdd = true;
                  prop?.isEdit = true;
                  //prop.size = true;
                  prop?.isDisplayField = true;
                  prop?.isGrid = false;
                  prop?.readOnly = false;
                  prop?.isRequired = r['isRequired'] ?? false;
                  return prop!;
                }).toList(),
                defaultFilter ?? []));
        if (result == null) canceled = true;
        if ((result as List<EntityFilter>?) == null)
          result = List.empty(growable: true);
        filter = result
                ?.where((f) =>
                    f.value != null &&
                    f.property != null &&
                    f.propertyName != null &&
                    f.operatorId != null)
                .toList() ??
            [];
      }
      if (!canceled) {
        for (var m in report['filters']) {
          if (m['isRequired'] == true &&
              !filter.any((p) => p.propertyName == m['dbName'])) {
            await AppNavigator.showMessage(
                context, 'Data Missing', MessageType.warning,
                message: m['nameAr']);
            await onOpenReport(context, report, filter);
            return;
          }
        }
        AppNavigator.navigateTo(
            context, () => ReportDetailPage(report, filter));
      }
    } catch (err, t) {
      print(err);
      print(t);
    }
  }

  static Future saveTableColumnSort(bool isEditing, List<ReportProperty> prop,
      context, dynamic reportName, int sortColumnIndex, bool sortAcd) async {
    print('------------  saveTableColumnSort  Method ---------------');
    Map<String, Map<String, dynamic>> data = {};
    if (!isEditing) {
      print('Saving Table Sort --- Name:  ${reportName['dbName']}');
      for (var i = 0; i < prop.length; i++) {
        data['$i'] = {
          'dbName': prop[i].dbName,
          'nameAr': prop[i].nameAr,
          'type': prop[i].type.index,
          'nameEn': prop[i].nameEn,
        };
      }
      data['sortColumnIndex'] = {'sortColumnIndex': sortColumnIndex};
      data['sortAcd'] = {'sortAcd': sortAcd};
      print(data);
      bool isSaved = await ConfigService.setValueMap(
          'Report_${reportName['dbName']}', data);
      if (isSaved) {
        await AppNavigator.showMessage(
            context,
            LocalConfigService.isArabic
                ? 'تم حفظ ترتيب أعمدة الجدول'
                : 'Sorting Columns of Tables Saved Successfully',
            MessageType.info);
      }
    }
    return data;
  }
}

==> tecfy_corev2_package-1.1.100.tar.gz: lib/services/report.service.dart <==
part of tecfy_corev2_client_package;

class ReportDataService {
  static Future onOpenReport(BuildContext context, Map<String, dynamic> report,
      [List<EntityFilter>? defaultFilter, bool? isLite]) async {
    // AppNavigator.navigateTo(context, ()=>ReportFilterPage(report));
    try {
      List<EntityFilter> filter = [];
      bool canceled = false;
      if (!report.containsKey("filters")) {
        report['filters'] = report['criteria']
            .map((value) => ({
                  ...Map<String, dynamic>.from(value['property']),
                  "name": value['name']
                }))
            .toList();
        report['filters'] = List<Map<String, dynamic>>.from(report['filters']);
      }

      report['properties'] = report['properties']
          .map((value) => {
                ...value['property'],
                "type": value['property']['valueType'],
                "sortId": value['sortId'],
                "name": value['name']
              })
          .toList();
      if (report['filters'].length > 0) {
        var result = await AppNavigator.showAppDialog(
            context,
            (c) => EntityFilterPage(
                report['filters'].map<Property>((r) {
                  var prop = Property.getProperty(r);
                  //prop.isVisable = true;
                  prop?.isAdd = true;
                  prop?.isEdit = true;
                  //prop.size = true;
                  prop?.isDisplayField = true;
                  prop?.isGrid = false;
                  prop?.readOnly = false;
                  prop?.isRequired = r['isRequired'] ?? false;
                  return prop!;
                }).toList(),
                defaultFilter ?? []));
        if (result == null) canceled = true;
        if ((result as List<EntityFilter>?) == null)
          result = List.empty(growable: true);
        filter = result
                ?.where((f) =>
                    f.value != null &&
                    f.property != null &&
                    f.propertyName != null &&
                    f.operatorId != null)
                .toList() ??
            [];
      }
      if (!canceled) {
        for (var m in report['filters']) {
          // if (m['isRequired'] == true &&
          //     !filter.any((p) => p.propertyName == m['dbName'])) {
          //   await AppNavigator.showMessage(
          //       context, 'Data Missing', MessageType.warning,
          //       message: m['nameAr']);
          //   await onOpenReport(context, report, filter);
          //   return;
          // }
        }
        AppNavigator.navigateTo(context,
            () => ReportDetailPage(report, filter, isLite: isLite ?? false));
      }
    } catch (err, t) {
      print(err);
      print(t);
    }
  }

  static Future saveTableColumnSort(bool isEditing, List<ReportProperty> prop,
      context, dynamic reportName, int sortColumnIndex, bool sortAcd) async {
    print('------------  saveTableColumnSort  Method ---------------');
    Map<String, Map<String, dynamic>> data = {};
    if (!isEditing) {
      print('Saving Table Sort --- Name:  ${reportName['dbName']}');
      for (var i = 0; i < prop.length; i++) {
        data['$i'] = {
          'dbName': prop[i].dbName,
          'nameAr': prop[i].nameAr,
          'type': prop[i].type.index,
          'nameEn': prop[i].nameEn,
        };
      }
      data['sortColumnIndex'] = {'sortColumnIndex': sortColumnIndex};
      data['sortAcd'] = {'sortAcd': sortAcd};
      print(data);
      bool isSaved = await ConfigService.setValueMap(
          'Report_${reportName['dbName']}', data);
      if (isSaved) {
        await AppNavigator.showMessage(
            context,
            LocalConfigService.isArabic
                ? 'تم حفظ ترتيب أعمدة الجدول'
                : 'Sorting Columns of Tables Saved Successfully',
            MessageType.info);
      }
    }
    return data;
  }
}
